@@ -213,10 +213,7 @@ SEXP mmap_mmap (SEXP _type, SEXP _fildesc, SEXP _prot,
 
 
   SEXP mmap_obj;
-  PROTECT(mmap_obj = allocSExp(ENVSXP));
-  SET_FRAME(mmap_obj, R_NilValue);
-  SET_ENCLOS(mmap_obj, R_NilValue);
-  SET_HASHTAB(mmap_obj, R_NilValue);
+  PROTECT(mmap_obj = R_NewEnv(R_NilValue, FALSE, 0));
   SET_ATTRIB(mmap_obj, R_NilValue);
   defineVar(mmap_dataSymbol, R_MakeExternalPtr(data, R_NilValue, R_NilValue),mmap_obj);
   //defineVar(install("bytes"), ScalarReal(asReal(_len)-asInteger(_off)-asInteger(_pageoff)),mmap_obj);
@@ -255,10 +252,7 @@ SEXP mmap_mmap (SEXP _type, SEXP _fildesc, SEXP _prot,
   data = data + asInteger(_pageoff); /* advance ptr to byte offset from page boundary */
   
   SEXP mmap_obj;
-  PROTECT(mmap_obj = allocSExp(ENVSXP));
-  SET_FRAME(mmap_obj, R_NilValue);
-  SET_ENCLOS(mmap_obj, R_NilValue);
-  SET_HASHTAB(mmap_obj, R_NilValue);
+  PROTECT(mmap_obj = R_NewEnv(R_NilValue, FALSE, 0));
   SET_ATTRIB(mmap_obj, R_NilValue);
   defineVar(mmap_dataSymbol, R_MakeExternalPtr(data, R_NilValue, R_NilValue),mmap_obj);
   //defineVar(install("bytes"), ScalarReal(asReal(_len)-asInteger(_off)-asInteger(_pageoff)),mmap_obj);
